@@ -22,19 +22,26 @@
 
 #include "pa_utils.h"
 
+#include <QSettings>
 #include <QString>
 #include <QLineEdit>
 
 #include "analogmeterwidget.h"
 #include "horizontalvolumebarwidget.h"
+#include "settingsdialog.h"
 #include "volumelinechartwidget.h"
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
+    QCoreApplication::setOrganizationName("VU Meter");
+    QCoreApplication::setOrganizationDomain("https://garage.maemo.org/projects/vumeter");
+    QCoreApplication::setApplicationName("VU Meter");
+
     ui->setupUi(this);
 
+    process = NULL;
     meter = 0;
     volumeMeterWidget = NULL;
     changeMeter();
@@ -75,17 +82,24 @@ MainWindow::MainWindow(QWidget *parent) :
 
     connect(ui->radioButtonDb, SIGNAL(clicked()), this, SLOT(setDbScale()));
     connect(ui->radioButtonLinear, SIGNAL(clicked()), this, SLOT(setLinearScale()));
+
+    connect(ui->actionSettings, SIGNAL(triggered()), this, SLOT(settingsDialog()));
 }
 
 MainWindow::~MainWindow()
 {
     delete ui;
 
-    if(volumeMeterWidget != NULL){
-        disconnect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
-        delete volumeMeterWidget;
+    if(process != NULL){
+        process->terminate();
+        delete process;
     }
 
+    if(sources != NULL){
+        delete sources;
+    }
+
+    delete volumeMeterWidget;
     pa_shutdown();
 }
 
@@ -109,14 +123,38 @@ void MainWindow::changeMeter(){
 
     volumeMeterWidget->setDbUnit(ui->radioButtonDb->isChecked());
     ui->volumeMeterLayout->addWidget(volumeMeterWidget);
+    getSettings();
     connect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
 }
 
+void MainWindow::getSettings(){
+    QSettings settings;
+    triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
+    triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
+
+    volumeMeterWidget->setTriggerValue(triggerValue);
+}
+
+void MainWindow::processFinished(){
+    if(process != NULL){
+        process->deleteLater();
+        process = NULL;
+    }
+}
+
 void MainWindow::resetMaxValue(){
     maxVol = 0;
     ui->maximumVolume->setNum(maxVol);
 }
 
+void MainWindow::settingsDialog(){
+    SettingsDialog dialog(this);
+
+    if(dialog.exec()){
+        getSettings();
+    }
+}
+
 void MainWindow::setLinearScale(){
     volumeMeterWidget->setDbUnit(false);
     resetMaxValue();
@@ -162,6 +200,12 @@ void MainWindow::updateValues(float value){
         vol = 0;
     }
 
+    if(vol > triggerValue && process == NULL){
+        process = new QProcess();
+        connect(process, SIGNAL(finished(int)), this, SLOT(processFinished()));
+        process->start(triggerCommand);
+    }
+
     volumeMeterWidget->updateValue(vol);
     ui->currentVolume->setNum(vol);
     if(maxVol < vol){
