@@ -26,15 +26,15 @@ VolumeMeterWidget::VolumeMeterWidget(QWidget *parent) :
     QGLWidget(QGLFormat(QGL::SampleBuffers), parent)
 {
     currentValue = 0;
+    triggerIndicatorColor = Qt::darkYellow;
+    triggerValue = 0;
     background = NULL;
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 }
 
-VolumeMeterWidget::~VolumeMeterWidget()
-{
+VolumeMeterWidget::~VolumeMeterWidget(){
     if(background != NULL){
         delete background;
-        background = NULL;
     }
 }
 
@@ -49,6 +49,15 @@ void VolumeMeterWidget::calculateSize(){
     }
 }
 
+void VolumeMeterWidget::drawBackground(QPainter *painter){
+    painter->drawImage(QRect(0, 0, w, h),
+                       *background,
+                       QRect(0, 0, w, h));
+}
+
+void VolumeMeterWidget::drawTriggerIndicator(QPainter */*painter*/){
+}
+
 void VolumeMeterWidget::initBackground(){
     if(background != NULL){
         delete background;
@@ -76,17 +85,44 @@ void VolumeMeterWidget::paintEvent(QPaintEvent */*event*/){
 
     initPainter(& painter);
 
+    if(background == NULL){
+        initBackground();
+        prepareBackground();
+    }
+
+    drawBackground(& painter);
+
+    if(triggerValue > 0){
+        drawTriggerIndicator(& painter);
+    }
+
     draw(& painter);
 }
 
+void VolumeMeterWidget::prepareBackground(){
+}
+
 void VolumeMeterWidget::resizeEvent(QResizeEvent */*event*/){
-    background = NULL;
+    if(background != NULL){
+        delete background;
+        background = NULL;
+    }
 }
 
 void VolumeMeterWidget::setDbUnit(bool b){
     dbUnit = b;
     currentValue = 0;
-    background = NULL;
+
+    if(background != NULL){
+        delete background;
+        background = NULL;
+    }
+
+    emit update();
+}
+
+void VolumeMeterWidget::setTriggerValue(int value){
+    triggerValue = value;
     emit update();
 }
 
